Struct language_e2e_tests::executor::FakeExecutor [−][src]
pub struct FakeExecutor { /* fields omitted */ }Expand description
Provides an environment to run a VM instance.
This struct is a mock in-memory implementation of the Diem executor.
Implementations
Creates an executor from a genesis WriteSet.
Create an executor from a saved genesis blob
Creates an executor from the genesis file GENESIS_FILE_LOCATION
Creates an executor using the standard genesis.
Creates an executor using the experimental genesis.
Creates an executor from the genesis file GENESIS_FILE_LOCATION with script/module
publishing options given by publishing_options. These can only be either Open or
CustomScript.
Creates an executor in which no genesis state has been applied yet.
Creates an executor with only the standard library Move modules published and not other initialization done.
pub fn custom_genesis(
genesis_modules: &[Vec<u8>],
validator_accounts: Option<usize>,
publishing_options: VMPublishingOption
) -> Self
pub fn custom_genesis(
genesis_modules: &[Vec<u8>],
validator_accounts: Option<usize>,
publishing_options: VMPublishingOption
) -> Self
Creates fresh genesis from the stdlib modules passed in.
Create one instance of AccountData without saving it to data store.
Create one instance of AccountData without saving it to data store.
Create one instance of AccountData with XDX balance without saving it to data store.
Creates a number of Account instances all with the same balance and sequence number,
and publishes them to this executor’s data store.
Applies a WriteSet to this executor’s data store.
Adds an account to this executor’s data store.
Adds a module to this executor’s data store.
Does not do any sort of verification on the module.
Reads the resource [Value] for an account from this executor’s data store.
pub fn read_account_resource_at_address(
&self,
addr: &AccountAddress
) -> Option<DiemAccountResource>
pub fn read_account_resource_at_address(
&self,
addr: &AccountAddress
) -> Option<DiemAccountResource>
Reads the resource [Value] for an account under the given address from
this executor’s data store.
pub fn read_balance_resource(
&self,
account: &Account,
balance_currency_code: Identifier
) -> Option<BalanceResource>
pub fn read_balance_resource(
&self,
account: &Account,
balance_currency_code: Identifier
) -> Option<BalanceResource>
Reads the balance resource value for an account from this executor’s data store with the given balance currency_code.
pub fn read_balance_resource_at_address(
&self,
addr: &AccountAddress,
balance_currency_code: Identifier
) -> Option<BalanceResource>
pub fn read_balance_resource_at_address(
&self,
addr: &AccountAddress,
balance_currency_code: Identifier
) -> Option<BalanceResource>
Reads the balance resource value for an account under the given address from this executor’s data store with the given balance currency_code.
pub fn execute_block(
&self,
txn_block: Vec<SignedTransaction>
) -> Result<Vec<TransactionOutput>, VMStatus>
pub fn execute_block(
&self,
txn_block: Vec<SignedTransaction>
) -> Result<Vec<TransactionOutput>, VMStatus>
Executes the given block of transactions.
Typical tests will call this method and check that the output matches what was expected. However, this doesn’t apply the results of successful transactions to the data store.
pub fn execute_block_and_keep_vm_status(
&self,
txn_block: Vec<SignedTransaction>
) -> Result<Vec<(VMStatus, TransactionOutput)>, VMStatus>
pub fn execute_block_and_keep_vm_status(
&self,
txn_block: Vec<SignedTransaction>
) -> Result<Vec<(VMStatus, TransactionOutput)>, VMStatus>
Alternate form of ‘execute_block’ that keeps the vm_status before it goes into the
TransactionOutput
Executes the transaction as a singleton block and applies the resulting write set to the data store. Panics if execution fails
pub fn execute_transaction_block_parallel(
&self,
txn_block: Vec<Transaction>
) -> Result<Vec<TransactionOutput>, VMStatus>
pub fn execute_transaction_block(
&self,
txn_block: Vec<Transaction>
) -> Result<Vec<TransactionOutput>, VMStatus>
Get the blob for the associated AccessPath
Verifies the given transaction by running it through the VM verifier.